@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: create_zip.py 10389 2017-10-22 05:43:34Z Lavender $
+# $Id: create_zip.py 10574 2017-11-29 03:26:17Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-10-22 13:43:34 +0800 (Sun, 22 Oct 2017) $
-# $Revision: 10389 $
+# $Date: 2017-11-29 11:26:17 +0800 (週三, 29 十一月 2017) $
+# $Revision: 10574 $
 
 import os
 import shutil
@@ -23,6 +23,7 @@ import hashlib
 
 from django.core.management.base import BaseCommand, CommandError
 from django.template.loader import get_template
+from django.template import Context
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH, 
@@ -56,12 +57,28 @@ class Command(BaseCommand):
             for root, dirs, files in os.walk(TEMPLATES_DIR_PATH):
                 for temp in files:
                     with open(os.path.join(root, temp)) as f:
-                        content += f.read()
+                        htmlContent = f.read()
+                    htmlContent = htmlContent.replace(
+                        "<!--### include _tracking.html ###-->",
+                        "{% include '_tracking.html' %}")
+                    with open(os.path.join(root, temp), 'wb') as f:
+                        f.write(htmlContent.encode('utf8'))
+                    content += htmlContent
             data['checksum'] = hashlib.md5(content).hexdigest()
 
+            upc = data['upc']
+            complexity = data['complexity']
+
             with open(os.path.join(ROOT_DIR_PATH, 'info.json'), 'w') as f:
                 line = json.dumps(data)
                 f.write(line)
+
+            context = Context({'upc': upc, 'complexity': complexity})
+            temp = get_template('boilerplate/html/Tracking.html')
+            content = temp.render(context)
+            with open(os.path.join(
+                TEMPLATES_DIR_PATH, '_tracking.html'), 'wb') as f:
+                f.write(content.encode('utf8'))
                 
         templateName = options['templateName']
 
@@ -90,9 +107,13 @@ class Command(BaseCommand):
                 path = 'fixtures/%s' % f
                 logger.info("Zip " + path)
                 zip.write(path)
-                
+
+        if os.path.isfile(os.path.join(ROOT_DIR_PATH, 'info.json')):
+            context = Context({'upc': upc,})
+        else:
+            context = Context({'upc': None,})
         temp = get_template('boilerplate/py/setup.py')
-        content = temp.render()
+        content = temp.render(context)
         with open(os.path.join(ROOT_DIR_PATH, 'setup.py'), 'wb') as f:
             f.write(content.encode('utf8'))
             
