@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10570 2017-11-28 08:48:05Z Lavender $
+# $Id: setup.py 10574 2017-11-29 03:26:17Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-11-28 16:48:05 +0800 (Tue, 28 Nov 2017) $
-# $Revision: 10570 $ 
+# $Date: 2017-11-29 11:26:17 +0800 (週三, 29 十一月 2017) $
+# $Revision: 10574 $ 
 
 import os
 import sys
@@ -69,7 +69,8 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
                     dst = os.path.join(templateDir, f)
                 else:
                     if not result.endswith("_user"):
-                        continue
+                        if not result.endswith("_tracking"):
+                            continue
                     dst = os.path.join(
                         templateDir, f.replace('_user.html', '.html'))
             elif os.path.join(SETUP_DIR, "fixtures") in root:
@@ -347,5 +348,25 @@ if __name__ == "__main__":
         logger.info("Get into \"%s\" directory and type"
                     " \"python manage.py runserver\" to start your project" % 
                     path)
+
+    {% if upc %}
+    tid = 'UA-110201703-1'
+    cid = '{{ upc }}'
+    ec = "Product"
+    ea = "Setup"
+    el = "upc={{ upc }}"
+    url = ("https://www.google-analytics.com/collect?"
+           "v=1&t=event&tid=%s&cid=%s&ec=%s&ea=%s&el=%s&ev=300" % (
+               tid, cid, ec, ea, el))
+    try:
+        if sys.version_info.major == 3:
+            import urllib.request
+            result = urllib.request.urlopen(url)
+        else:
+            import urllib2
+            result = urllib2.urlopen(url)
+    except Exception as e:
+        pass
+    {% endif %}
     
     
\ No newline at end of file
